# TEOBResumS: Effective-one-body model for compact binary waveforms

## Pre-requisites

 * C compiler (e.g. GCC)
 * [GSL library](https://www.gnu.org/software/gsl/)

## Usage

To start, checkout the [Wiki](https://bitbucket.org/eob_ihes/teobresums/wiki/browse/).

### Python extension

```
$ python
>>> import EOBRun_module
```

Example scripts for using the python module can be found in `Python/Examples/` [here](https://bitbucket.org/eob_ihes/teobresums/src/master/Python/Examples/).

## References

Please, consult the complete list of [references on the Wiki](https://bitbucket.org/eob_ihes/teobresums/wiki/References) and cite papers according to what you use.

## Developers

Please contact Sebastiano Bernuzzi and Alessandro Nagar if you wish to be included in the list of developers.

A short description of the code can be found in [here](C/README.md). Please, take a moment to understand the data structures and how the parameters are managed.

See [here](https://bitbucket.org/eob_ihes/teobresums/wiki/EOB-repo-usage) for a description of the workflow of this repo.

If you want to start a new branch or development make sure to

 * Talk to us 
 * Run the benchmark *before* applying any change 
 * Run the benchmark *after* you applied your changes and before pushing them; compare and make sure you did not break anything.

## Contact

You can get in contact with TEOBResumS developers and fellow users through our mailing list. To subscribe please click on the badge below.

[![Mailing List](https://img.shields.io/badge/mailing%20list-join-informational)](https://lserv.uni-jena.de/mailman/listinfo/teobresums)
